@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2014 the original author or authors.
+ * Copyright 2012-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -39,7 +39,7 @@ class ProjectGenerator {
 
 	private final InitializrService initializrService;
 
-	public ProjectGenerator(InitializrService initializrService) {
+	ProjectGenerator(InitializrService initializrService) {
 		this.initializrService = initializrService;
 	}
 
@@ -70,6 +70,9 @@ class ProjectGenerator {
 
 	/**
 	 * Detect if the project should be extracted.
+	 * @param request the generation request
+	 * @param response the generation response
+	 * @return if the project should be extracted
 	 */
 	private boolean shouldExtract(ProjectGenerationRequest request,
 			ProjectGenerationResponse response) {
@@ -90,6 +93,7 @@ class ProjectGenerator {
 				return ZIP_MIME_TYPE.equals(entity.getContentType().getMimeType());
 			}
 			catch (Exception ex) {
+				// Ignore
 			}
 		}
 		return false;
@@ -106,6 +110,8 @@ class ProjectGenerator {
 				new ByteArrayInputStream(entity.getContent()));
 		try {
 			extractFromStream(zipStream, overwrite, outputFolder);
+			fixExecutableFlag(outputFolder, "mvnw");
+			fixExecutableFlag(outputFolder, "gradlew");
 			Log.info("Project extracted to '" + outputFolder.getAbsolutePath() + "'");
 		}
 		finally {
@@ -154,4 +160,11 @@ class ProjectGenerator {
 		Log.info("Content saved to '" + output + "'");
 	}
 
+	private void fixExecutableFlag(File dir, String fileName) {
+		File f = new File(dir, fileName);
+		if (f.exists()) {
+			f.setExecutable(true, false);
+		}
+	}
+
 }
