@@ -73,6 +73,11 @@ public enum Environment {
      */
     public static String RELOAD_ENABLED = "grails.reload.enabled";
 
+    /**
+     * Constant indicating whether run-app or test-app was executed
+     */
+    public static String RUN_ACTIVE = "grails.run.active";
+
     /**
      * Whether the display of full stack traces is needed
      */
@@ -268,6 +273,16 @@ public enum Environment {
     public static boolean isDevelopmentEnvironmentAvailable() {
         return BuildSettings.GRAILS_APP_DIR_PRESENT ;
     }
+
+    /**
+     * This method will return true the application is run
+     *
+     * @return True if the development sources are present
+     */
+    public static boolean isDevelopmentRun() {
+        Environment env = Environment.getCurrent();
+        return BuildSettings.GRAILS_APP_DIR_PRESENT && Boolean.getBoolean(RUN_ACTIVE) && (env == Environment.DEVELOPMENT);
+    }
     /**
      * Check whether the application is deployed
      * @return true if is
@@ -277,8 +292,11 @@ public enum Environment {
         if(loadedLocation != null && loadedLocation.getPath().contains("/WEB-INF/classes")) {
             return true;
         }
+        // Workaround for weblogic who repacks files from 'classes' into a new jar under lib/
+        if (loadedLocation != null && loadedLocation.getPath().contains("_wl_cls_gen.jar!/")) {
+            return true;
+        }
         return false;
-
     }
 
     /**
